Coverage for src/paperap/models/config/config.py: 0%

1"""

2----------------------------------------------------------------------------

3

4 METADATA:

5

6 File: config.py

7 Project: paperap

8 Created: 2025-03-04

9 Version: 0.0.5

10 Author: Jess Mann

11 Email: jess@jmann.me

12 Copyright (c) 2025 Jess Mann

13

14----------------------------------------------------------------------------

15

16 LAST MODIFIED:

17

18 2025-03-04 By Jess Mann

19

20"""

21

22 from __future__ import annotations

23

24 from datetime import datetime

25 from typing import Any, Optional

26

27 from paperap.models.abstract.model import StandardModel

28

29

30 class Config(StandardModel):

31 user_args: str | None = None

32 output_type: str | None = None

33 pages: str | None = None

34 language: str | None = None

35 mode: str | None = None

36 skip_archive_file: bool | None = None

37 image_dpi: int | None = None

38 unpaper_clean: bool | None = None

39 deskew: bool

40 rotate_pages: bool

41 rotate_pages_threshold: int | None = None

42 max_image_pixels: int | None = None

43 color_conversion_strategy: str | None = None

44 app_title: str

45 app_logo: str